@@ -7,7 +7,7 @@
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
 # License as published by the Free Software Foundation; either
-# version 2 of the License, or (at your option) any later version.
+# version 2.1 of the License, or (at your option) any later version.
 #
 # This library is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -19,7 +19,6 @@
 #
 # Author: David Zeuthen <davidz@redhat.com>
 
-DATADIR = "${prefix}/share"
-DATADIR = DATADIR.replace(
-    "${prefix}", "/usr/pkg")
-VERSION = "2.52.3"
+VERSION = "2.78.1"
+MAJOR_VERSION = 2
+MINOR_VERSION = 78
